==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/test_runner/transl/turkish.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr" sourcelanguage="en">
<context>
    <name>ExcludeReasonDialog</name>
    <message>
        <location filename="../src/ExcludeReasonDialog.ui" line="20"/>
        <source>exclude reason</source>
        <translation>nedeni hariç tut</translation>
    </message>
    <message>
        <location filename="../src/ExcludeReasonDialog.ui" line="35"/>
        <source>Set exclude reason</source>
        <translation>Hariç tutma nedenini ayarlayın</translation>
    </message>
</context>
<context>
    <name>TestView</name>
    <message>
        <location filename="../src/TestView.ui" line="14"/>
        <source>Test Runner</source>
        <translation>Test Çalıştırıcısı</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="28"/>
        <source>testColumn</source>
        <translation>test Sütunu</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="33"/>
        <source>stateColumn</source>
        <translation>durum Sütunu</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="65"/>
        <source>info_label</source>
        <translation>bilgi_etiketi</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="112"/>
        <source>Save test</source>
        <translation>Testi kaydet</translation>
    </message>
</context>
<context>
    <name>U2::TestRunnerPlugin</name>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="55"/>
        <source>test_runner_plug_name</source>
        <translation>test_çalıştırıcısı_eklenti_adı</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="55"/>
        <source>test_runner_desc</source>
        <translation>test_çalıştırıcısı_azalan</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="96"/>
        <location filename="../src/TestRunnerPlugin.cpp" line="107"/>
        <source>Can&apos;t load suite %1</source>
        <translation>%1 paketi yüklenemiyor</translation>
    </message>
</context>
<context>
    <name>U2::TestRunnerService</name>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="138"/>
        <location filename="../src/TestRunnerPlugin.cpp" line="167"/>
        <source>Test runner</source>
        <translation>Test Çalıştırıcısı</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="138"/>
        <source>Service to support UGENE embedded testing</source>
        <translation>UGENE yerleşik testini destekleme hizmeti</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="277"/>
        <source>Error reading test suite from %1. Error: %2</source>
        <translation>%1 kaynağından test paketi okunurken hata oluştu. Hata: %2</translation>
    </message>
</context>
<context>
    <name>U2::TestViewController</name>
    <message>
        <location filename="../src/TestViewController.cpp" line="432"/>
        <location filename="../src/TestViewController.cpp" line="471"/>
        <location filename="../src/TestViewController.cpp" line="779"/>
        <location filename="../src/TestViewController.cpp" line="798"/>
        <source>error</source>
        <translation>hata</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="930"/>
        <source>info</source>
        <translation>bilgi</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="937"/>
        <source>env_mb_title</source>
        <translation>env_mb_başlığı</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1142"/>
        <source>passed</source>
        <translation>geçti</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1145"/>
        <source>failed</source>
        <translation>başarısız</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1147"/>
        <source>not_run</source>
        <translation>çalıştır_ma</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1180"/>
        <source>state: </source>
        <translation>durum: </translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1182"/>
        <source>fail_desc: </source>
        <translation>başarısız_azalma: </translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1185"/>
        <source>source_file:</source>
        <translation>kaynak_dosyası:</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="72"/>
        <source>Test runner</source>
        <translation>Test çalıştırıcısı</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="83"/>
        <source>Add suite</source>
        <translation>Paket ekle</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="87"/>
        <source>Remove suite</source>
        <translation>Paketi kaldır</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="91"/>
        <source>Run all tests</source>
        <translation>Tüm testleri çalıştırın</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="95"/>
        <source>Run selected</source>
        <translation>Seçileni çalıştır</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="101"/>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="105"/>
        <source>Set environment</source>
        <translation>Ortamı ayarla</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="109"/>
        <source>Generate report</source>
        <translation>Rapor oluştur</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="113"/>
        <source>Reload suites</source>
        <translation>Paketleri yeniden yükle</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="118"/>
        <source>Select All</source>
        <translation>Tümünü seç</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="124"/>
        <source>Set Tests Enabled</source>
        <translation>Etkinleştirilen Testleri Ayarla</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="130"/>
        <source>Set Tests Disabled</source>
        <translation>Testleri Devre Dışı Bırak</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="136"/>
        <source>Change Tests Excluded State</source>
        <translation>Testlerin Hariç Tutulma Durumunu Değiştirin</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="140"/>
        <source>Save Selected Suites</source>
        <translation>Seçili Paketleri Kaydet</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="432"/>
        <source>Error reading test suites: 

 %1</source>
        <translation>Test paketleri okunurken hata oluştu:

 %1</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="447"/>
        <source>Select test suite file</source>
        <translation>Test paketi dosyasını seçin</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="471"/>
        <source>Error reading test suite: %1</source>
        <translation>Test paketi okunurken hata oluştu: %1</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="779"/>
        <location filename="../src/TestViewController.cpp" line="798"/>
        <source>Not all environment variables set</source>
        <translation>Tüm ortam değişkenleri ayarlanmadı</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="930"/>
        <source>No environment variables found</source>
        <translation>Ortam değişkeni bulunamadı</translation>
    </message>
</context>
</TS>

==> ugene_52.1+dfsg.orig.tar.xz: ugene-52.1/src/plugins/test_runner/transl/turkish.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr" sourcelanguage="en">
<context>
    <name>ExcludeReasonDialog</name>
    <message>
        <location filename="../src/ExcludeReasonDialog.ui" line="20"/>
        <source>exclude reason</source>
        <translation>nedeni hariç tut</translation>
    </message>
    <message>
        <location filename="../src/ExcludeReasonDialog.ui" line="35"/>
        <source>Set exclude reason</source>
        <translation>Hariç tutma nedenini ayarlayın</translation>
    </message>
</context>
<context>
    <name>TestView</name>
    <message>
        <location filename="../src/TestView.ui" line="14"/>
        <source>Test Runner</source>
        <translation>Test Çalıştırıcısı</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="28"/>
        <source>testColumn</source>
        <translation>test Sütunu</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="33"/>
        <source>stateColumn</source>
        <translation>durum Sütunu</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="65"/>
        <source>info_label</source>
        <translation>bilgi_etiketi</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="112"/>
        <source>Save test</source>
        <translation>Testi kaydet</translation>
    </message>
</context>
<context>
    <name>U2::TestRunnerPlugin</name>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="56"/>
        <source>Test Runner</source>
        <translation>Test Çalıştırıcısı</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="56"/>
        <source>Support for running runs XML tests from GUI &amp; console interfaces.</source>
        <translation>Arayüz ve konsol arayüzlerinden XML testleri çalıştırma desteği.</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="103"/>
        <source>Can&apos;t load suite %1</source>
        <translation>%1 paketi yüklenemiyor</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="115"/>
        <source>Can&apos;t load suite %1, errors: %2</source>
        <translation>%1 paketi yüklenemiyor, hatalar: %2</translation>
    </message>
    <message>
        <source>test_runner_plug_name</source>
        <translation type="vanished">test_çalıştırıcısı_eklenti_adı</translation>
    </message>
    <message>
        <source>test_runner_desc</source>
        <translation type="vanished">test_çalıştırıcısı_azalan</translation>
    </message>
</context>
<context>
    <name>U2::TestRunnerService</name>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="146"/>
        <source>Test runner</source>
        <translation>Test Çalıştırıcısı</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="146"/>
        <source>Service to support UGENE embedded testing</source>
        <translation>UGENE yerleşik testini destekleyen hizmet</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="175"/>
        <source>XML Test runner</source>
        <translation>XML Test Çalıştırıcısı</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="287"/>
        <source>Error reading test suite from %1. Error: %2</source>
        <translation>%1 kaynağından test paketi okunurken hata oluştu. Hata: %2</translation>
    </message>
</context>
<context>
    <name>U2::TestViewController</name>
    <message>
        <location filename="../src/TestViewController.cpp" line="432"/>
        <location filename="../src/TestViewController.cpp" line="471"/>
        <location filename="../src/TestViewController.cpp" line="774"/>
        <location filename="../src/TestViewController.cpp" line="793"/>
        <source>error</source>
        <translation>hata</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="925"/>
        <source>info</source>
        <translation>bilgi</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="932"/>
        <source>env_mb_title</source>
        <translation>env_mb_başlığı</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1137"/>
        <source>passed</source>
        <translation>geçti</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1140"/>
        <source>failed</source>
        <translation>başarısız</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1142"/>
        <source>not_run</source>
        <translation>çalıştır_ma</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1175"/>
        <source>state: </source>
        <translation>durum: </translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1177"/>
        <source>fail_desc: </source>
        <translation>başarısız_azalma: </translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1180"/>
        <source>source_file:</source>
        <translation>kaynak_dosyası:</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="72"/>
        <source>Test runner</source>
        <translation>Test çalıştırıcısı</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="83"/>
        <source>Add suite</source>
        <translation>Paket ekle</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="87"/>
        <source>Remove suite</source>
        <translation>Paketi kaldır</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="91"/>
        <source>Run all tests</source>
        <translation>Tüm testleri çalıştırın</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="95"/>
        <source>Run selected</source>
        <translation>Seçileni çalıştır</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="101"/>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="105"/>
        <source>Set environment</source>
        <translation>Ortamı ayarla</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="109"/>
        <source>Generate report</source>
        <translation>Rapor oluştur</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="113"/>
        <source>Reload suites</source>
        <translation>Paketleri yeniden yükle</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="118"/>
        <source>Select All</source>
        <translation>Tümünü Seç</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="124"/>
        <source>Set Tests Enabled</source>
        <translation>Etkinleştirilen Testleri Ayarla</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="130"/>
        <source>Set Tests Disabled</source>
        <translation>Testleri Devre Dışı Bırak</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="136"/>
        <source>Change Tests Excluded State</source>
        <translation>Testlerin Hariç Tutulma Durumunu Değiştirin</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="140"/>
        <source>Save Selected Suites</source>
        <translation>Seçili Paketleri Kaydet</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="432"/>
        <source>Error reading test suites: 

 %1</source>
        <translation>Test paketleri okunurken hata oluştu:

 %1</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="447"/>
        <source>Select test suite file</source>
        <translation>Test paketi dosyasını seçin</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="471"/>
        <source>Error reading test suite: %1</source>
        <translation>Test paketi okunurken hata oluştu: %1</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="774"/>
        <location filename="../src/TestViewController.cpp" line="793"/>
        <source>Not all environment variables set</source>
        <translation>Tüm ortam değişkenleri ayarlanmadı</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="925"/>
        <source>No environment variables found</source>
        <translation>Ortam değişkeni bulunamadı</translation>
    </message>
</context>
</TS>
